#_____________________________________________________________________________________
#
# Exempelkod för att hämta data från statistikdabasen (statistik.konj.se) och kombinera
# ihop serier från olika uttag
# Example code for fetching data from the statistical database (statistik.konj.se) and
# combining series from different queries.
#
# Du behöver installera pyjstat, skriv följande i kommandotolken
# You need to install pyjstat, in the command prompt write the following
#
# py -m pip install pyjstat
#_____________________________________________________________________________________

#_____________________________________________________________________________________

from pyjstat import pyjstat
import requests
from matplotlib import pyplot as plt
import pandas as pd

# Hämta månadsdata för byggindustri, efter att en tabell har genererats
# från databasen, är URL:en och den faktiska JSON-förfrågan belägna längst ner

# Fetch monthly data for construction industry, after a table has been generated
# from the database, the URL and the actual JSON query are located at the bottom.

# Ange URL:en
# Input the URL
POST_URL_BYGG = 'https://statistik.konj.se:443/PxWeb/api/v1/sv/KonjBar/ftgmanad/Barboam.px'

# Ange JSON-förfrågan
# Input the JSON query
bygg_payload = {
  "query": [
    {
      "code": "Bransch (SNI 2007)",
      "selection": {
        "filter": "item",
        "values": [
          "BBYG"
        ]
      }
    },
    {
      "code": "Fråga",
      "selection": {
        "filter": "item",
        "values": [
          "106"
        ]
      }
    },
    {
      "code": "Serie",
      "selection": {
        "filter": "item",
        "values": [
          "S"
        ]
      }
    }
  ],
  "response": {
     # Observera att 'format':'px' har ändrats till JSON-stat
     # Note that 'format':'px' has been changed to JSON-stat
    "format": "json-stat"
  }
}

# Ladda data, mm
# Load data, etc
response_bygg = requests.post(POST_URL_BYGG,json = bygg_payload)
print(response_bygg)
dataset_bygg = pyjstat.Dataset.read(response_bygg.text)
df_bygg = dataset_bygg.write('dataframe')
df_bygg["Period"] = pd.to_datetime(df_bygg["Period"], format = "%YM%m")

#_____________________________________________________________________________________

# Återupprepa datauttaget för ytterligare tre serier
# Repeat the data extraction for three additional series

# Handeln
# Trade

POST_URL_HANDEL = 'https://statistik.konj.se:443/PxWeb/api/v1/sv/KonjBar/ftgmanad/Barhanm.px'

handel_payload = {
  "query": [
    {
      "code": "Bransch (SNI 2007)",
      "selection": {
        "filter": "item",
        "values": [
          "BHAN"
        ]
      }
    },
    {
      "code": "Fråga",
      "selection": {
        "filter": "item",
        "values": [
          "104"
        ]
      }
    },
    {
      "code": "Serie",
      "selection": {
        "filter": "item",
        "values": [
          "S"
        ]
      }
    }
  ],
  "response": {
    "format": "json-stat"
  }
}

response_handel = requests.post(POST_URL_HANDEL,json = handel_payload)
print(response_handel)
dataset_handel = pyjstat.Dataset.read(response_handel.text)
df_handel = dataset_handel.write('dataframe')
df_handel["Period"] = pd.to_datetime(df_handel["Period"], format = "%YM%m")

# Tillverkningsindustri
# Manufacturing industry

POST_URL_TILLV = 'https://statistik.konj.se:443/PxWeb/api/v1/sv/KonjBar/ftgmanad/Barindm.px'

payload_tillv = {
  "query": [
    {
      "code": "Bransch (SNI 2007)",
      "selection": {
        "filter": "item",
        "values": [
          "BTVI"
        ]
      }
    },
    {
      "code": "Fråga",
      "selection": {
        "filter": "item",
        "values": [
          "107"
        ]
      }
    },
    {
      "code": "Serie",
      "selection": {
        "filter": "item",
        "values": [
          "S"
        ]
      }
    }
  ],
  "response": {
    "format": "json-stat" # <- Notera att jag ändrat från px till json-stat för att kunna läsa in
  }
}

response_tillv = requests.post(POST_URL_TILLV,json = payload_tillv)
print(response_tillv)
dataset_tillv = pyjstat.Dataset.read(response_tillv.text)
df_tillv = dataset_tillv.write('dataframe')
print(df_tillv.head())
df_tillv["Period"] = pd.to_datetime(df_tillv["Period"], format = "%YM%m")

# Tjänstesektorn
# Service sector

POST_URL_TJANST = 'https://statistik.konj.se:443/PxWeb/api/v1/sv/KonjBar/ftgmanad/Bartjam.px'


payload_tjanst = {
  "query": [
    {
      "code": "Bransch (SNI 2007)",
      "selection": {
        "filter": "item",
        "values": [
          "BTJA"
        ]
      }
    },
    {
      "code": "Fråga",
      "selection": {
        "filter": "item",
        "values": [
          "105"
        ]
      }
    },
    {
      "code": "Serie",
      "selection": {
        "filter": "item",
        "values": [
          "S"
        ]
      }
    }
  ],
  "response": {
    "format": "json-stat" # <- Notera att jag ändrat från px till json-stat för att kunna läsa in
  }
}

response_tjanst = requests.post(POST_URL_TJANST,json = payload_tjanst)
print(response_tillv)
dataset_tjanst = pyjstat.Dataset.read(response_tjanst.text)
df_tjanst = dataset_tjanst.write('dataframe')
print(df_tjanst.head())
df_tjanst["Period"] = pd.to_datetime(df_tjanst["Period"], format = "%YM%m")

# _____________________________________________________________________________________

# Skapa graf
# Create graph

plt.figure(figsize = (8,6),dpi=100)

plt.plot(df_bygg["Period"],df_bygg["value"],label = df_bygg["Bransch (SNI 2007)"].loc[0])
plt.plot(df_handel["Period"],df_handel["value"],label = df_handel["Bransch (SNI 2007)"].loc[0])
plt.plot(df_tillv["Period"],df_tillv["value"],label = df_tillv["Bransch (SNI 2007)"].loc[0])
plt.plot(df_tjanst["Period"],df_tjanst["value"],label = df_tjanst["Bransch (SNI 2007)"].loc[0])


plt.axhline(0, linestyle = "--", color="grey", lw =1)
plt.grid(axis = 'y', color = "lightgrey", alpha=0.3)

plt.legend()

plt.title("Antal anställda (utfall), nettotal, 1996-2024, \n" "månatlig frekvens")
plt.show()








